# Catalog Metadata

The SDK automatically generates catalog metadata during catalog discovery. Selection rules overridden by a user will be respected.

Primary key properties may not be deselected, as these are required for `key_properties` to be declared in stream messages.

## Additional Singer Metadata References

- [Singer Spec: Metadata](https://hub.meltano.com/singer/spec#metadata)
